@@ -3,7 +3,7 @@
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
 // 
-// Copyright (c) 2009-2014 Icinga Developer Team.
+// Copyright (c) 2009-2015 Icinga Developer Team.
 // All rights reserved.
 // 
 // icinga-web is free software: you can redistribute it and/or modify
@@ -27,9 +27,13 @@ class LocalConsoleConnection extends BaseConsoleConnection {
     public function exec(Api_Console_ConsoleCommandModel $cmd) {
         $cmdString = $cmd->getCommandString();
         $this->checkFileExistence($cmd);
-        
+
+        $username = AppKitAgaviUtil::getContext()->getUser()->getNsmUser()->user_name;
+        putenv('ICINGAWEB_USER=' . $username);
+        putenv('ICINGAWEB_IP=' . $_SERVER['REMOTE_ADDR']);
+
         exec($cmdString,$out,$ret);
-        
+
         $cmd->setReturnCode($ret);
         $cmd->setOutput($out);
     }
