@@ -2,7 +2,7 @@
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
 //
-// Copyright (c) 2009-2014 Icinga Developer Team.
+// Copyright (c) 2009-2015 Icinga Developer Team.
 // All rights reserved.
 // 
 // icinga-web is free software: you can redistribute it and/or modify
@@ -421,13 +421,32 @@ Ext.ns('Cronk.grid');
 
 
             case 'checkbox':
+                var clistener = function (checkedBox,val) {
+                    var affectedForms = ['duration', 'duration-minute', 'duration-hour'];
+                    for (var i = 0; i < affectedForms.length; i++) {
+                        var m = form.getForm().findField(affectedForms[i]);
+                        if (m) {
+                            m.setReadOnly((checkedBox.initialConfig.boxLabel === _('No')) ? !val : val);
+                            m.container.setVisible((checkedBox.initialConfig.boxLabel === _('No')) ? val : !val);
+                        }
+                    }
+                };
+                var initialListener = function(c) {
+                    Ext.iterate(c.findByType('checkbox'), function(item, idx) {
+                        if (item.getValue() === true) {
+                            item.fireEvent('check', item, true);
+                        }
+                    }, c);
+                    c.removeListener('afterlayout', initialListener);
+                }
+
                 Ext.apply(oDef, {
                     name: o.fieldName + '-group',
                     layout: 'column',
                     items: [{
                         xtype: 'radio',
                         boxLabel: _('Yes'),
-                        inputValue: 1,
+                        inputValue: o.fieldYesValue || 1,
                         columnWidth: 0.35,
                         name: o.fieldName,
                         checked: o.fieldValue !== "true"
@@ -438,22 +457,12 @@ Ext.ns('Cronk.grid');
                         name: o.fieldName,
                         columnWidth: 0.65,
                         checked: o.fieldValue === "true"
-                    }]
-                });
-
-                var clistener = function (checkedBox,val) {
-                    for (var i = 0; i < affectedForms.length; i++) {
-                        var m = form.getForm().findField(affectedForms[i]);
-
-                        if (m) {
-                            m.setReadOnly((checkedBox.initialConfig.boxLabel === _('No')) ? !val : val);
-                            m.container.setVisible((checkedBox.initialConfig.boxLabel === _('No')) ? val : !val);
-                        }
+                    }],
+                    listeners: {
+                        afterlayout: initialListener
                     }
-                };
-
+                });
                 if (o.fieldName === "fixed") {
-                    var affectedForms = ['duration', 'duration-minute', 'duration-hour'];
                     for(var i=0;i<oDef.items.length;i++) {
                         oDef.items[i].listeners = {
                             check: clistener
@@ -726,6 +735,7 @@ Ext.ns('Cronk.grid');
                             fieldValue: this.command_options.predefined[item] || o.types[item].defaultValue || "",
                             fieldChecked: o.types[item].defaultChecked || "",
                             fieldRequired: o.types[item].required == "true",
+                            fieldYesValue: o.types[item].yesValue || null,
                             form: oForm
                         });
 
