@@ -3,7 +3,7 @@
 // -----------------------------------------------------------------------------
 // This file is part of icinga-web.
 // 
-// Copyright (c) 2009-2014 Icinga Developer Team.
+// Copyright (c) 2009-2015 Icinga Developer Team.
 // All rights reserved.
 // 
 // icinga-web is free software: you can redistribute it and/or modify
@@ -49,7 +49,7 @@
     </head>
     <body>
         <noscript>
-            <div style="margin:auto;margin-top:10%;width:500px;text-align:center;padding:5px;-webkit-border-radius:5px;-moz-border-radius:5px;border:1px solid black;background-color:#dedede">
+            <div style="margin:auto;margin-top:10%;width:500px;text-align:center;padding:5px;-webkit-border-radius:5px;-moz-border-radius:5px;border-radius:5px;border:1px solid black;background-color:#dedede">
                 <h1>Oops...JavaScript support is disabled!</h1>
                 You have to activate JavaScript in order to use Icinga-web.
             </div>
